@@ -4,15 +4,10 @@ from ._main import Plotter, plot, plot_abs, plot_arg, plot_contours, plot_phase
 from ._riemann_sphere import riemann_sphere
 from ._tri import tricontour_abs, tripcolor
 from .benchmark import show_kovesi_test_image, show_test_function
-from .create import create_colormap, find_max_srgb_radius, show_circular, show_linear
 
 __all__ = [
     "show_test_function",
     "show_kovesi_test_image",
-    "show_linear",
-    "show_circular",
-    "find_max_srgb_radius",
-    "create_colormap",
     "get_srgb1",
     "plot",
     "plot_arg",
