@@ -90,6 +90,7 @@ def _add_colorbar_abs(cax, abs_scaling: Callable, abs_contours: float | list[flo
     )
     cb0.set_label("abs", rotation=0, ha="center", va="top")
     cb0.ax.yaxis.set_label_coords(0.5, -0.03)
+
     if isinstance(abs_contours, (int, float)):
         a = abs_contours
         scaled_vals = abs_scaling(
@@ -163,11 +164,14 @@ def _plot_contour_abs(
 
         minval = np.nanmin(vals)
         min_exp = -np.inf if minval == 0.0 else np.log(minval) / np.log(base)
-        min_exp = int(max(min_exp, -max_num_contours))
+
+        mx = max(min_exp, -max_num_contours)
+        min_exp = 0 if np.isnan(mx) else int(mx)
 
         maxval = np.nanmax(vals)
         max_exp = np.log(maxval) / np.log(base)
-        max_exp = int(min(max_exp, max_num_contours))
+        mn = min(max_exp, max_num_contours)
+        max_exp = 0 if np.isnan(mn) else int(mn)
 
         # exclude exponent 0, that's treated separately below
         contours_neg = [base**k for k in range(min_exp, 0)]
@@ -314,10 +318,11 @@ def _plot(
 
     if contours_abs is None:
         contours_abs = 2
+
     elif contours_abs == "auto":
         assert isinstance(
             abs_scaling, (int, float)
-        ), f"abs_scaling must be int or float, not {abs_scaling}"
+        ), f'if contours_abs="auto", abs_scaling must be int or float, not {abs_scaling}'
         contours_abs = abs_scaling
 
     if contours_abs is not None:
